<?php
/**
*
* @package hjw multi_language_forum_name Extension
* @copyright (c) 2019 hjw
* @license http://opensource.org/licenses/gpl-2.0.php GNU General Public License v2
*
*/

namespace hjw\multilanguageforumname\event;

/**
* @ignore
*/
use Symfony\Component\EventDispatcher\EventSubscriberInterface;

/**
* Event listener
*/
class main_listener implements EventSubscriberInterface
{
	public static function getSubscribedEvents()
	{
		return array(
			'core.user_setup'										=> 'load_language_on_setup',
			'core.page_header'										=> 'multi_language_page_title',
			'core.page_header_after'								=> 'multi_language_sitename',
			'core.display_forums_modify_template_vars'				=> 'multi_language_forum_titel',
			'core.display_forums_modify_category_template_vars'		=> 'multi_language_forum_titel2',
			'core.generate_forum_nav'								=> 'multi_language_forum_nav',
			'core.make_jumpbox_modify_tpl_ary'						=> 'multi_language_forum_titel_jumpbox',
			'core.search_modify_tpl_ary'							=> 'multi_language_forum_titel_search',
			'core.viewonline_modify_user_row'						=> 'multi_language_who_is_online',
			'core.viewtopic_assign_template_vars_before'			=> 'multi_language_viewtopic',
			'core.search_modify_forum_select_list'					=> 'multi_language_search_forum_list',
			'core.acp_manage_forums_modify_forum_list'				=> 'multi_language_acp_manage_forum_list',
			'core.viewforum_modify_page_title'						=> 'multi_language_forum_rules',
			'core.posting_modify_template_vars'						=> 'multi_language_posting_forum_name',
			'core.posting_modify_submit_post_before'				=> 'multi_language_forum_rules',
			'core.ucp_main_subscribed_forum_modify_template_vars'	=> 'multi_language_ucp_subscribed',
			'core.make_forum_select_modify_forum_list'				=> 'multi_language_forum_list',
		);
	}

	/** @var \phpbb\language\language */
	protected $language;

	/** @var \phpbb\template\template */
	protected $template;

	/** @var \phpbb\config\config */
	protected $config;

	/**
	* Constructor
	*
	* @param \phpbb\language\language		$this->language
	* @param \phpbb\template\template		$this->config
	* @param \phpbb\config\config		$this->config
	*/

	public function __construct(\phpbb\language\language $language, \phpbb\template\template $template, \phpbb\config\config $config)
	{
		$this->language	= $language;
		$this->template	= $template;
		$this->config	= $config;
	}

	public function multi_language_page_title($event)
	{
		$event['page_title'] = $this->language->lang($event['page_title']);
	}

	public function multi_language_sitename()
	{
		$this->template->assign_vars(array(
			'SITENAME'			=> $this->language->lang($this->config['sitename']),
			'SITE_DESCRIPTION'	=> $this->language->lang($this->config['site_desc']),
		));
	}

	public function multi_language_forum_titel($event)
	{
		$row = $event['forum_row'];
		$row['FORUM_NAME'] = $this->language->lang($row['FORUM_NAME']);
		$row['FORUM_DESC'] = $this->language->lang($row['FORUM_DESC']);
		$event['forum_row'] = $row;
	}

	public function multi_language_forum_titel2($event)
	{
		$row = $event['cat_row'];
		$row['FORUM_NAME'] = $this->language->lang($row['FORUM_NAME']);
		$row['FORUM_DESC'] = $this->language->lang($row['FORUM_DESC']);
		$event['cat_row'] = $row;
	}

	public function multi_language_forum_nav($event)
	{
		$row = $event['navlinks_parents'];
		for ($i=0; $i<count($row); $i++)
		{
			if ($this->config['version'] < '3.3.0')
			{
				$row[$i]['FORUM_NAME'] = $this->language->lang($row[$i]['FORUM_NAME']);
			}
			if ($this->config['version'] >= '3.3.0')
			{
				$row[$i]['BREADCRUMB_NAME'] = $this->language->lang($row[$i]['BREADCRUMB_NAME']);
			}
		}
		$event['navlinks_parents'] = $row;

		$row = $event['navlinks'];
		if ($this->config['version'] < '3.3.0')
		{
			$row['FORUM_NAME'] = $this->language->lang($row['FORUM_NAME']);
		}
		if ($this->config['version'] >= '3.3.0')
		{
			$row['BREADCRUMB_NAME'] = $this->language->lang($row['BREADCRUMB_NAME']);
		}
		$event['navlinks'] = $row;

		$row = $event['forum_template_data'];
		$row['FORUM_NAME'] = $this->language->lang($row['FORUM_NAME']);
		$row['FORUM_DESC'] = $this->language->lang($row['FORUM_DESC']);
		$event['forum_template_data'] = $row;
	}

	public function multi_language_forum_titel_jumpbox($event)
	{
		$row = $event['tpl_ary'];
		foreach ($row as $nr => $forum_row)
		{
			$row[$nr]['FORUM_NAME'] = $this->language->lang($forum_row['FORUM_NAME']);
		}
		$event['tpl_ary'] = $row;
	}

	public function multi_language_forum_titel_search($event)
	{
		$row = $event['tpl_ary'];
		$row['FORUM_TITLE'] = $this->language->lang($row['FORUM_TITLE']);
		$event['tpl_ary'] = $row;
	}

	public function load_language_on_setup($event)
	{
		$lang_set_ext = $event['lang_set_ext'];
		$lang_set_ext[] = array(
			'ext_name' => 'hjw/multilanguageforumname',
			'lang_set' => 'multilanguageforumname',
		);
		$event['lang_set_ext'] = $lang_set_ext;
	}

	public function multi_language_who_is_online($event)
	{
		$row 			= $event['row'];
		$template_row	= $event['template_row'];
		$forum_data		= $event['forum_data'];
		if ($row['session_forum_id'])
		{
			$template_row['FORUM_LOCATION'] = str_replace($forum_data[$row['session_forum_id']]['forum_name'],$this->language->lang($forum_data[$row['session_forum_id']]['forum_name']),$template_row['FORUM_LOCATION']);
			$event['template_row'] = $template_row;
		}
	}

	public function multi_language_search_forum_list($event)
	{
		$row 			= $event['rowset'];
		foreach ($row as $nr => $forum_row)
		{
			$row[$nr]['forum_name'] = $this->language->lang($forum_row['forum_name']);
		}
		$event['rowset'] = $row;
	}

	public function multi_language_acp_manage_forum_list($event)
	{
		$rowset = $event['rowset'];
		foreach ($rowset as $nr => $row)
		{
			$row['forum_name'] = $this->language->lang($row['forum_name']);
			$row['forum_desc'] = $this->language->lang(strip_tags($row['forum_desc']));
			$rowset[$nr] = $row;
		}
		$event['rowset'] = $rowset;
	}

	public function multi_language_viewtopic($event)
	{
		$row = $event['topic_data'];
		$row['forum_name'] = $this->language->lang($row['forum_name']);
		$row['forum_desc'] = $this->language->lang(strip_tags($row['forum_desc']));
		$row['forum_rules'] = $this->language->lang(strip_tags($row['forum_rules']));
		$event['topic_data'] = $row;
		if ($row['forum_rules'] && $this->language->lang($row['forum_rules']))
		{
			$this->template->assign_vars(array(
				'FORUM_RULES'	=> $this->language->lang($row['forum_rules']),
			));
		}
	}

	public function multi_language_forum_rules($event)
	{
		$row = $event['forum_data'];
		if ($row)
		{
			if ($row['forum_rules'] && $this->language->lang($row['forum_rules']))
			{
				$this->template->assign_vars(array(
					'FORUM_RULES'	=> $this->language->lang($row['forum_rules']),
				));
			}
		}
	}
	public function multi_language_posting_forum_name($event)
	{
		$row = $event['page_data'];
		$row['FORUM_NAME'] = $this->language->lang($row['FORUM_NAME']);
		$row['FORUM_DESC'] = $this->language->lang(strip_tags($row['FORUM_DESC']));
		$event['page_data'] = $row;

		$row = $event['post_data'];
		if ($row['forum_rules'] && $this->language->lang($row['forum_rules']))
		{
			$this->template->assign_vars(array(
				'FORUM_RULES'	=> $this->language->lang($row['forum_rules']),
			));
		}
	}
	public function multi_language_ucp_subscribed($event)
	{
		$row = $event['template_vars'];
		$row['FORUM_NAME'] = $this->language->lang($row['FORUM_NAME']);
		$row['FORUM_DESC'] = $this->language->lang(strip_tags($row['FORUM_DESC']));
		$event['template_vars'] = $row;
	}
	public function multi_language_forum_list($event)
	{
		$rowset = $event['rowset'];
		foreach ($rowset as $nr => $row)
		{
			$row['forum_name'] = $this->language->lang($row['forum_name']);
			$rowset[$nr] = $row;
		}
		$event['rowset'] = $rowset;
	}
}
